@@ -51,7 +51,7 @@ pub struct Transmiter {
     event_consumer: TransmitEventConsumer,
 
     subscriberid_to_producer: Arc<Mutex<HashMap<Uuid, ChannelDataProducer>>>,
-    
+
     cache: Arc<Mutex<Cache>>,
 }
 
@@ -106,6 +106,15 @@ impl Transmiter {
                                                 value: ChannelErrorValue::SendError,
                                             })?;
                                         }
+
+                                        let gop = self.cache.lock().unwrap().clone().get_gop_data();
+                                        if let Some(gop_data) = gop{
+                                            for channel_data in gop_data{
+                                                sender.send(channel_data).map_err(|_| ChannelError {
+                                                    value: ChannelErrorValue::SendError,
+                                                })?;
+                                            }
+                                        }
                                      }
                                     SessionSubType::Publisher =>{
 
@@ -225,7 +234,7 @@ impl ChannelsManager {
         self.event_loop().await;
     }
 
-    pub fn set_push_enabled(&mut self, enabled: bool) {
+    pub fn set_rtmp_push_enabled(&mut self, enabled: bool) {
         self.push_enabled = enabled;
     }
 
@@ -233,7 +242,7 @@ impl ChannelsManager {
         self.hls_enabled = enabled;
     }
 
-    pub fn set_pull_enabled(&mut self, enabled: bool) {
+    pub fn set_rtmp_pull_enabled(&mut self, enabled: bool) {
         self.pull_enabled = enabled;
     }
 
@@ -302,8 +311,6 @@ impl ChannelsManager {
         }
     }
 
-    pub async fn data_loop(&mut self) {}
-
     //player subscribe a stream
     pub async fn subscribe(
         &mut self,
@@ -311,42 +318,27 @@ impl ChannelsManager {
         stream_name: &String,
         session_info: SessionInfo,
     ) -> Result<mpsc::UnboundedReceiver<ChannelData>, ChannelError> {
-        match self.channels.get_mut(app_name) {
-            Some(val) => match val.get_mut(stream_name) {
-                Some(producer) => {
-                    let (sender, receiver) = oneshot::channel();
+        if let Some(val) = self.channels.get_mut(app_name) {
+            if let Some(producer) = val.get_mut(stream_name) {
+                let (sender, receiver) = oneshot::channel();
 
-                    let event = TransmitEvent::Subscribe {
-                        responder: sender,
-                        session_info,
-                    };
-                    producer.send(event).map_err(|_| ChannelError {
-                        value: ChannelErrorValue::SendError,
-                    })?;
+                let event = TransmitEvent::Subscribe {
+                    responder: sender,
+                    session_info,
+                };
 
-                    match receiver.await {
-                        Ok(consumer) => {
-                            log::info!("subscribe get consumer successfully, app_name: {}, stream_name: {}",app_name,stream_name);
-                            return Ok(consumer);
-                        }
-                        Err(_) => {
-                            // return Err(ChannelError {
-                            //     value: ChannelErrorValue::NoStreamName,
-                            // });
-                        }
-                    }
+                producer.send(event).map_err(|_| ChannelError {
+                    value: ChannelErrorValue::SendError,
+                })?;
+
+                if let Ok(consumer) = receiver.await {
+                    log::info!(
+                        "subscribe get consumer successfully, app_name: {}, stream_name: {}",
+                        app_name,
+                        stream_name
+                    );
+                    return Ok(consumer);
                 }
-                None => {
-                    // return Err(ChannelError {
-                    //     value: ChannelErrorValue::NoStreamName,
-                    // })
-                }
-            },
-            None => {
-
-                // return Err(ChannelError {
-                //     value: ChannelErrorValue::NoAppName,
-                // })
             }
         }
 
@@ -443,6 +435,12 @@ impl ChannelsManager {
                         stream_name_clone,
                         err,
                     );
+                } else {
+                    log::info!(
+                        "transmiter exists: app_name: {}, stream_name: {}",
+                        app_name_clone,
+                        stream_name_clone
+                    );
                 }
             });
 
@@ -500,9 +498,6 @@ impl ChannelsManager {
 
         Ok(())
     }
-
-    //server broadcast data to player
-    pub fn broadcast() {}
 }
 
 #[cfg(test)]
