@@ -3,13 +3,13 @@ extern crate bytes;
 extern crate chrono;
 extern crate failure;
 extern crate hmac;
-extern crate networkio;
+extern crate bytesio;
 extern crate rand;
 extern crate sha2;
 extern crate tokio;
 
 pub mod amf0;
-pub mod relay;
+pub mod cache;
 pub mod channels;
 pub mod chunk;
 pub mod config;
@@ -18,7 +18,8 @@ pub mod messages;
 pub mod netconnection;
 pub mod netstream;
 pub mod protocol_control_messages;
+pub mod relay;
+pub mod rtmp;
 pub mod session;
 pub mod user_control_messages;
 pub mod utils;
-pub mod cache;
