@@ -1,5 +1,8 @@
 use {
-    crate::amf0::errors::{Amf0ReadError, Amf0WriteError},
+    crate::{
+        amf0::errors::{Amf0ReadError, Amf0WriteError},
+        chunk::errors::PackError,
+    },
     failure::{Backtrace, Fail},
     std::fmt,
 };
@@ -14,6 +17,8 @@ pub enum NetConnectionErrorValue {
     Amf0WriteError(Amf0WriteError),
     #[fail(display = "amf0 read error: {}\n", _0)]
     Amf0ReadError(Amf0ReadError),
+    #[fail(display = "pack error\n")]
+    PackError(PackError),
 }
 
 impl From<Amf0WriteError> for NetConnectionError {
@@ -32,6 +37,14 @@ impl From<Amf0ReadError> for NetConnectionError {
     }
 }
 
+impl From<PackError> for NetConnectionError {
+    fn from(error: PackError) -> Self {
+        NetConnectionError {
+            value: NetConnectionErrorValue::PackError(error),
+        }
+    }
+}
+
 impl fmt::Display for NetConnectionError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         fmt::Display::fmt(&self.value, f)
